@@ -1,9 +1,11 @@
 import random
 from collections import defaultdict
-from typing import Dict, Any, TYPE_CHECKING, Generator
-from ...helper import dunder_get
+from typing import Dict, Any, TYPE_CHECKING, Generator, List
+
 import numpy as np
 
+from ...helper import dunder_get
+
 if TYPE_CHECKING:
     from ... import DocumentArray
 
@@ -64,3 +66,30 @@ class GroupMixin:
 
         for i in range(n_batches):
             yield self[ix[i * batch_size : (i + 1) * batch_size]]
+
+    def batch_ids(
+        self,
+        batch_size: int,
+        shuffle: bool = False,
+    ) -> Generator[List[str], None, None]:
+        """
+        Creates a `Generator` that yields `lists of ids` of size `batch_size` until `self` is fully traversed.
+        Note, that the last batch might be smaller than `batch_size`.
+
+        :param batch_size: Size of each generated batch (except the last one, which might be smaller)
+        :param shuffle: If set, shuffle the Documents before dividing into minibatches.
+        :yield: a Generator of `list` of IDs, each in the length of `batch_size`
+        """
+
+        if not (isinstance(batch_size, int) and batch_size > 0):
+            raise ValueError('`batch_size` should be a positive integer')
+
+        N = len(self)
+        ix = self[:, 'id']
+        n_batches = int(np.ceil(N / batch_size))
+
+        if shuffle:
+            random.shuffle(ix)
+
+        for i in range(n_batches):
+            yield ix[i * batch_size : (i + 1) * batch_size]
